@@ -3,8 +3,8 @@ use intspan::*;
 use std::io::BufRead;
 
 // Create clap subcommand arguments
-pub fn make_subcommand<'a>() -> App<'a> {
-    App::new("range")
+pub fn make_subcommand<'a>() -> Command<'a> {
+    Command::new("range")
         .about("Convert runlist file to ranges file")
         .arg(
             Arg::new("runlist")
