@@ -4,8 +4,8 @@ use serde_yaml::Value;
 use std::collections::BTreeMap;
 
 // Create clap subcommand arguments
-pub fn make_subcommand<'a>() -> App<'a> {
-    App::new("stat")
+pub fn make_subcommand<'a>() -> Command<'a> {
+    Command::new("stat")
         .about("Coverage on chromosomes for runlists")
         .arg(
             Arg::new("chr.sizes")
