@@ -4,12 +4,12 @@ use clap::*;
 mod cmd_far;
 
 fn main() -> std::io::Result<()> {
-    let app = App::new("far")
+    let app = Command::new("far")
         .version(crate_version!())
         .author(crate_authors!())
         .about("`far` is a lightweight tool for operating sequences in the fasta format")
-        .global_setting(AppSettings::PropagateVersion)
-        .global_setting(AppSettings::ArgRequiredElseHelp)
+        .propagate_version(true)
+        .arg_required_else_help(true)
         .subcommand(cmd_far::size::make_subcommand())
         .subcommand(cmd_far::some::make_subcommand())
         .subcommand(cmd_far::region::make_subcommand());
